@@ -52,9 +52,9 @@ class CommsThread:
         _encoded = base64.b64encode(bytes(_toencode, encoding="utf8"))
 
         _invalid = False
-
-        if not config_entry.data[CONF_HOST].startswith("http://"):
-            config_entry.data[CONF_HOST] = "http://" + config_entry.data[CONF_HOST]
+        _host_with_http = config_entry.data[CONF_HOST]
+        if not _host_with_http.startswith("http://"):
+            _host_with_http = f"http://{_host_with_http}"
 
         authenticate = aiohttp.BasicAuth(
             config_entry.data[CONF_USERNAME], config_entry.data[CONF_PASSWORD],
@@ -81,7 +81,7 @@ class CommsThread:
                 async with aiohttp.ClientSession(timeout=_TIMEOUT) as session:
                     try:  # try to get sens_out.json
                         async with session.get(
-                            config_entry.data[CONF_HOST] + "/sens_out.json",
+                            f"{_host_with_http}/sens_out.json",
                             auth=authenticate,
                             data=_post,
                         ) as response:
@@ -92,10 +92,10 @@ class CommsThread:
                                 _LOGGER.debug("Invalid sens_out.json")
                                 server_status = "Invalid"
                                 _invalid = True
-                    except:  # try to get output.json
-                        try:
+                    except:
+                        try:  # try to get output.json
                             async with session.get(
-                                config_entry.data[CONF_HOST] + "/output.json",
+                                f"{_host_with_http}/output.json",
                                 auth=authenticate,
                                 data=_post,
                             ) as response:
@@ -202,7 +202,7 @@ class CommsThread:
                     if server_status == "Online-2":
                         try:  # try to get sens_out.json
                             async with session.get(
-                                config_entry.data[CONF_HOST] + "/sens_out.json",
+                                f"{_host_with_http}/sens_out.json",
                                 auth=authenticate,
                                 data=_post,
                             ) as response:
@@ -228,7 +228,7 @@ class CommsThread:
                     else:
                         try:  # try to get output.json
                             async with session.get(
-                                config_entry.data[CONF_HOST] + "/output.json",
+                                f"{_host_with_http}/output.json",
                                 auth=authenticate,
                                 data=_post,
                             ) as response:
